function N = cginzland2d_N(y, t, problem)
% CGINZLAND2D_N -- Non-linear term of CGINZLAND2D equation.
%
% SYNOPSIS:
%   N = cginzland2d_N(y, t, problem);
% 
% DESCRIPTION:
%   Evaluates the non-linear term of the semi-discretised
%   complex Ginzburg-Landau 2D problem.
%
% PARAMETERS:
%   y    - Evaluation point in Fourier space (rolled out to vector)
%   t    - Evaluation point in time. Not used in this function.
%   problem - Problem dependent parameters.  
%             Should be defined by CGINZLAND2D.
%
% RETURNS:
%   N      - Value of non-linear term at `U'.
%
% SEE ALSO:
%   CGINZLAND2D

% This file is part of the 'Expint'-package,
% see http://www.math.ntnu.no/num/expint/
%
% $Revision: 1.1 $  $Date: 2005/05/05 13:48:16 $


% reshape into matrix form, still in fourier space:
uhat = reshape(y, [problem.ND, problem.ND]);

% Into physical space:
u = ifft2(uhat);


N = -1 * (1 + 1.0i*problem.beta) * fft2(u .* conj(u) .* u);
%N = 0*(1 + 1.0i*problem.a) * fft2(u .* conj(u) .* u);

% reshape into vector form, we are now in fourier space:

N = reshape(N, [problem.ND^2, 1]);
