function Nr = nls_N(U, t, problem)
% NLS_N - Non-linear term of NLS equation.
%
% SYNOPSIS:
%   Nr = nls_N(U, t, problem);
% 
% DESCRIPTION:
%   Evaluates the non-linear term of the semi-discretised non-linear
%   Schrdinger equation at a point `U' in Fourier space.
%
% PARAMETERS:
%   U       - Evaluation point in Fourier space.
%   t       - Evaluation point in time. Not used in this function.
%   problem - Problem dependent parameters.  Should be defined by NLS.
%
% RETURNS:
%   Nr      - Value of non-linear term at `U'.
%
% SEE ALSO:
%   NLS, NLS_L

% This file is part of the 'Expint'-package,
% see http://www.math.ntnu.no/num/expint/
%
% $Revision: 1.3 $  $Date: 2005/05/12 12:47:57 $

psi = ifft(U);
Nr  = -1i * fft((problem.v + (problem.lambda * psi .* conj(psi))) .* psi);
